import React from "react";
import { Device, DeviceApi, DeviceState } from "../../api/DeviceApi";
import { AsyncWidget } from "../../widgets/AsyncWidget";
import { DeviceRouteCard } from "./DeviceRouteCard";
import { Table, TableBody } from "@mui/material";
import { DeviceInfoProperty } from "./DeviceInfoProperty";
import { timeDiff } from "../../widgets/TimeWidget";

export function DeviceStateBlock(p: { device: Device }): React.ReactElement {
  const [state, setState] = React.useState<DeviceState>();

  const load = async () => {
    setState(await DeviceApi.GetSingleState(p.device.id));
  };

  return (
    <DeviceRouteCard title="Device state">
      <AsyncWidget
        loadKey={p.device.id}
        load={load}
        ready={!!state}
        errMsg="Failed to load device state!"
        build={() => <DeviceStateInner state={state!} />}
      />
    </DeviceRouteCard>
  );
}

function DeviceStateInner(p: { state: DeviceState }): React.ReactElement {
  return (
    <Table size="small">
      <TableBody>
        <DeviceInfoProperty
          label="Status"
          value={p.state.online ? "Online" : "Offline"}
        />
        <DeviceInfoProperty
          label="Last ping"
          value={timeDiff(0, p.state.last_ping)}
        />
      </TableBody>
    </Table>
  );
}
